whitespace

package
v0.0.27 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 13, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package whitespace applies XSD whiteSpace normalization rules.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ToRuntime

func ToRuntime(ws model.WhiteSpace) runtime.WhitespaceMode

ToRuntime converts a schema whitespace facet to runtime mode.

func ToValue

ToValue converts runtime whitespace mode to lexical normalization mode.

Types

This section is empty.

Jump to